@@ -257,6 +257,11 @@ class TestNamespace:
         assert ns.get('test_eval') == 'echo foo-bar'
         assert ns.test == 'foo-bar'
 
+    def test_duplicates(self) -> None:
+        """Namespace can find duplicate leaves in the tree."""
+        ns = Namespace({'a': {'x': 1, 'y': 2}, 'b': {'x': 3, 'z': 4}})
+        assert ns.duplicates() == {'x': [('a',), ('b',)]}
+
     def test_whereis(self) -> None:
         """Namespace can find paths to leaves in the tree."""
         ns = Namespace({'a': {'x': 1, 'y': 2}, 'b': {'x': 3, 'z': 4}})
@@ -515,6 +520,16 @@ class TestConfiguration:
         assert repr(cfg) == 'Configuration(a=Namespace({\'x\': 1}), _=Namespace({\'x\': 2, \'y\': 3}))'
         assert cfg.which('y') == '_'
 
+    def test_duplicates(self) -> None:
+        """Configuration can find duplicate leaves in the trees."""
+
+        one = Namespace({'a': {'x': 1, 'y': 2}, 'b': {'x': 3, 'z': 4}})
+        two = Namespace({'b': {'x': 4, 'z': 2}, 'c': {'j': True, 'k': 3.14}})
+        cfg = Configuration(one=one, two=two)
+
+        assert cfg.duplicates() == {'x': {'one': [('a',), ('b',)], 'two': [('b',)]},
+                                    'z': {'one': [('b',)], 'two': [('b',)]}}
+    
     def test_whereis(self) -> None:
         """Configuration can find paths to leaves in the tree."""
 
@@ -525,3 +540,23 @@ class TestConfiguration:
         assert cfg.whereis('x') == {'one': [('a',), ('b',)], 'two': [('b',)]}
         assert cfg.whereis('x', 1) == {'one': [('a',)], 'two': []}
         assert cfg.whereis('x', lambda v: v % 3 == 0) == {'one': [('b',)], 'two': []}
+
+    def test_pop(self) -> None:
+        """Configuration cannot use inherited pop method."""
+
+        one = Namespace({'a': {'x': 1, 'y': 2}, 'b': {'x': 3, 'z': 4}})
+        two = Namespace({'b': {'x': 4, 'z': 2}, 'c': {'j': True, 'k': 3.14}})
+        cfg = Configuration(one=one, two=two)
+
+        with pytest.raises(NotImplementedError):
+            cfg.pop('x')
+
+    def test_popitem(self) -> None:
+        """Configuration cannot use inherited popitem method."""
+
+        one = Namespace({'a': {'x': 1, 'y': 2}, 'b': {'x': 3, 'z': 4}})
+        two = Namespace({'b': {'x': 4, 'z': 2}, 'c': {'j': True, 'k': 3.14}})
+        cfg = Configuration(one=one, two=two)
+
+        with pytest.raises(NotImplementedError):
+            cfg.popitem()
